
import { useState, useEffect } from "react";
import { Button } from "@/components/ui/button";
import { Input } from "@/components/ui/input";
import { Label } from "@/components/ui/label";
import { Link, Navigate, useNavigate } from "react-router-dom";
import Layout from "@/components/Layout";
import { useAuth } from "@/contexts/AuthContext";
import { Alert, AlertDescription } from "@/components/ui/alert";
import { AlertCircle, Eye, EyeOff } from "lucide-react";
import { toast } from "sonner";
import { Card, CardHeader, CardTitle, CardDescription, CardContent, CardFooter } from "@/components/ui/card";

const Login = () => {
  const [email, setEmail] = useState("");
  const [password, setPassword] = useState("");
  const [error, setError] = useState("");
  const [isLoading, setIsLoading] = useState(true);
  const [showPassword, setShowPassword] = useState(false);
  const { signIn, loading: authLoading, user, userRoles } = useAuth();
  const navigate = useNavigate();

  // Log component state for debugging
  useEffect(() => {
    console.log("Login component - Current user:", user?.email);
    console.log("Login component - User roles:", userRoles);
    console.log("Login component - Loading status:", authLoading);
    
    // Set loading to false when auth data is ready
    if (!authLoading) {
      setIsLoading(false);
    }
  }, [user, userRoles, authLoading]);

  // If user is already logged in, redirect based on role
  useEffect(() => {
    if (user && !isLoading && userRoles.length > 0) {
      // Redirect to the appropriate dashboard based on the user's highest permission level
      if (userRoles.includes('admin')) {
        console.log("Redirecting to admin dashboard");
        navigate("/admin");
      } else if (userRoles.includes('vendor')) {
        console.log("Redirecting to vendor dashboard");
        navigate("/vendor");
      } else if (userRoles.includes('staff')) {
        console.log("Redirecting to staff POS dashboard");
        navigate("/pos");
      } else {
        console.log("Redirecting to user dashboard");
        navigate("/dashboard");
      }
    }
  }, [user, isLoading, userRoles, navigate]);

  const handleSubmit = async (e: React.FormEvent) => {
    e.preventDefault();
    setError("");
    try {
      const result = await signIn(email, password);
      console.log("Login result:", result);
      toast.success("Successfully logged in");
    } catch (error: any) {
      console.error("Login error:", error);
      setError(error.message || "Failed to sign in. Please try again.");
    }
  };

  // Toggle password visibility
  const togglePasswordVisibility = () => {
    setShowPassword(!showPassword);
  };

  // If loading, show loading indicator
  if (isLoading || authLoading) {
    return (
      <Layout title="Login" description="Logging in...">
        <div className="min-h-[70vh] flex flex-col items-center justify-center">
          <div className="animate-spin rounded-full h-12 w-12 border-4 border-t-brand-maroon border-r-brand-maroon border-b-transparent border-l-transparent"></div>
          <div className="mt-4 text-lg font-medium">Logging in...</div>
        </div>
      </Layout>
    );
  }

  return (
    <Layout title="Login" description="Sign in to access your Ghar-GharMaa services">
      <div className="flex items-center justify-center py-8 md:py-12 px-4 sm:px-6 lg:px-8">
        <Card className="w-full max-w-md animate-scale-in">
          <CardHeader className="space-y-1">
            <CardTitle className="text-center text-2xl md:text-3xl">
              Welcome back
            </CardTitle>
            <CardDescription className="text-center">
              Please sign in to access your services
            </CardDescription>
          </CardHeader>
          <CardContent>
            {error && (
              <Alert variant="destructive" className="mb-4">
                <AlertCircle className="h-4 w-4" />
                <AlertDescription>{error}</AlertDescription>
              </Alert>
            )}
            
            <form className="space-y-4 md:space-y-6" onSubmit={handleSubmit}>
              <div>
                <Label htmlFor="email">Email address</Label>
                <Input
                  id="email"
                  type="email"
                  placeholder="Enter your email"
                  value={email}
                  onChange={(e) => setEmail(e.target.value)}
                  required
                  className="mt-1"
                  disabled={isLoading || authLoading}
                />
              </div>
              <div>
                <div className="flex items-center justify-between">
                  <Label htmlFor="password">Password</Label>
                  <Link 
                    to="/forgot-password" 
                    className="text-sm text-brand-maroon hover:text-brand-dark-maroon"
                  >
                    Forgot password?
                  </Link>
                </div>
                <div className="relative">
                  <Input
                    id="password"
                    type={showPassword ? "text" : "password"}
                    placeholder="Enter your password"
                    value={password}
                    onChange={(e) => setPassword(e.target.value)}
                    required
                    className="mt-1 pr-10"
                    disabled={isLoading || authLoading}
                  />
                  <button
                    type="button"
                    className="absolute right-3 top-1/2 transform -translate-y-1/2 text-gray-500"
                    onClick={togglePasswordVisibility}
                  >
                    {showPassword ? (
                      <EyeOff className="h-4 w-4" />
                    ) : (
                      <Eye className="h-4 w-4" />
                    )}
                  </button>
                </div>
              </div>
              <Button type="submit" className="w-full" disabled={isLoading || authLoading}>
                {authLoading ? "Signing in..." : "Sign in"}
              </Button>
            </form>
          </CardContent>
          <CardFooter className="flex justify-center">
            <p className="text-sm text-muted-foreground">
              Don't have an account?{" "}
              <Link to="/signup" className="text-brand-maroon hover:text-brand-dark-maroon">
                Sign up
              </Link>
            </p>
          </CardFooter>
        </Card>
      </div>
    </Layout>
  );
};

export default Login;
